@@ -18,8 +18,8 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 # SPDX-License-Identifier: GPL-3.0-or-later
 __all__ = ["__version__", "logger"]
-__version__ = "0.1.2"
+__version__ = "0.4.0"
 import mylog
 
-logger = mylog.root.get_child()
+logger = mylog.root.get_child("lemming")
 logger.threshold = mylog.Level.info
